@@ -1,6 +1,6 @@
 /* shred.c - overwrite files and devices to make it harder to recover data
 
-   Copyright (C) 1999-2002 Free Software Foundation, Inc.
+   Copyright (C) 1999-2003 Free Software Foundation, Inc.
    Copyright (C) 1997, 1998, 1999 Colin Plumb.
 
    This program is free software; you can redistribute it and/or modify
@@ -110,23 +110,11 @@
 #include "inttostr.h"
 #include "quotearg.h"		/* For quotearg_colon */
 #include "quote.h"		/* For quotearg_colon */
-char *xstrdup PARAMS ((char const *));
 
 #ifndef O_NOCTTY
 # define O_NOCTTY 0  /* This is a very optional frill */
 #endif
 
-/* Some systems don't support some file types.  */
-#ifndef S_ISFIFO
-# define S_ISFIFO(mode) 0
-#endif
-#ifndef S_ISLNK
-# define S_ISLNK(mode) 0
-#endif
-#ifndef S_ISSOCK
-# define S_ISSOCK(mode) 0
-#endif
-
 #define DEFAULT_PASSES 25	/* Default */
 
 /* How many seconds to wait before checking whether to output another
@@ -152,7 +140,7 @@ static struct option const long_opts[] =
   {"size", required_argument, NULL, 's'},
   {"remove", no_argument, NULL, 'u'},
   {"verbose", no_argument, NULL, 'v'},
-  {"zero", required_argument, NULL, 'z'},
+  {"zero", no_argument, NULL, 'z'},
   {GETOPT_HELP_OPTION_DECL},
   {GETOPT_VERSION_OPTION_DECL},
   {NULL, 0, NULL, 0}
